@@ -247,12 +247,12 @@ while (<STDIN>){
 		$cfg{out_file}[0]=~s/\.ogm/\.avi/;
 	    }
 	    if(uc $v{save} ne 'AUTO'){
-		file_dialog(out_file_once, frames) || next;
+		if(!file_dialog(out_file_once, frames)) { print "run=0"; last};
 		$out_file=$cfg{out_file_once}[0];
 	    }elsif( $cfg{not_ask}[0] ){
 		$out_file=$cfg{out_file}[0];
 	    }else{
-		file_dialog(out_file, not_ask, frames) || next;
+		if(!file_dialog(out_file, not_ask, frames)) { print "run=0"; last};
 		$out_file=$cfg{out_file}[0];
 	    }
 	    if($cmd) {
@@ -276,6 +276,7 @@ while (<STDIN>){
 	    $OPTS.=" -fps '$v{fps}'"		if( $v{fps} );
 	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( exists $v{loop} );
 	    if(( $cmd2=rtpcmd() )) {
+		$cmd2.=" -k $v{frameskip}" if $v{frameskip};
 	        $cmd2="|exec $cmd2 2>/dev/null ".fileno(PIPE_OUT)."<&- >/dev/fd/".fileno(PIPE_IN);
 		$cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies -nocache /dev/fd/".fileno(PIPE_OUT);
 	        print "cmd=$cmd\n";
